import { join } from "path";
import { existsSync, readFileSync, writeFileSync } from "fs";
import { createHash } from "crypto";

export async function onBeforeComplete(options: IBuildTaskOption, cache: BuilderResultCache) {
    if (BUILDER.info.appVersion !== '1.0.3') {
        return;
    }
    // @ts-ignore
    const packageOptions = options.packages['wechatgame'];
    if (packageOptions.separateEngine && !options.debug) {
        const cocosDest = join(cache.destDir, 'cocos');
        const signatureJsonPath = join(cocosDest, 'signature.json');
        if (!existsSync(signatureJsonPath)) {
            return;
        }
        const engineName = options.buildEngineParam.engineName;
        const destEngine = readFileSync(join(cocosDest, engineName + '.js'));
        const md5 = createHash('md5');
        let signatureStr = readFileSync(join(cocosDest, 'signature.json'));
        const signatureJson = JSON.parse(signatureStr.toString());
        signatureJson.signature[0].md5 = md5.update(destEngine).digest('hex');
        writeFileSync(join(cocosDest, 'signature.json'), JSON.stringify(signatureJson));
		
		const gameJsonStr = readFileSync(join(cache.destDir, 'game.json'));
		const gameJson = JSON.parse(gameJsonStr.toString());
		gameJson.plugins.cocos.version = BUILDER.info.appVersion;
		writeFileSync(join(cache.destDir, 'game.json'), JSON.stringify(gameJson));
    }

}